@@ -33,6 +33,25 @@ const UNDIM_TIME = 0.250;
 const DISPLAY_REVERT_TIMEOUT = 20; // in seconds - keep in sync with mutter
 const ONE_SECOND = 1000; // in ms
 
+const GSD_WACOM_BUS_NAME = 'org.gnome.SettingsDaemon.Wacom';
+const GSD_WACOM_OBJECT_PATH = '/org/gnome/SettingsDaemon/Wacom';
+
+const GsdWacomIface = '<node name="/org/gnome/SettingsDaemon/Wacom"> \
+<interface name="org.gnome.SettingsDaemon.Wacom"> \
+  <method name="SetGroupModeLED"> \
+    <arg name="device_path" direction="in" type="s"/> \
+    <arg name="group" direction="in" type="u"/> \
+    <arg name="mode" direction="in" type="u"/> \
+  </method> \
+  <method name="SetOLEDLabels"> \
+    <arg name="device_path" direction="in" type="s"/> \
+    <arg name="labels" direction="in" type="as"/> \
+  </method> \
+  </interface> \
+</node>';
+
+const GsdWacomProxy = Gio.DBusProxy.makeProxyWrapper(GsdWacomIface);
+
 const DisplayChangeDialog = new Lang.Class({
     Name: 'DisplayChangeDialog',
     Extends: ModalDialog.ModalDialog,
@@ -535,6 +554,7 @@ Signals.addSignalMethods(TouchpadWorkspaceSwitchAction.prototype);
 const WorkspaceSwitchAction = new Lang.Class({
     Name: 'WorkspaceSwitchAction',
     Extends: Clutter.SwipeAction,
+    Signals: { 'activated': { param_types: [Meta.MotionDirection.$gtype] } },
 
     _init : function() {
         const MOTION_THRESHOLD = 50;
@@ -572,11 +592,11 @@ const WorkspaceSwitchAction = new Lang.Class({
         this.emit('activated', dir);
     }
 });
-Signals.addSignalMethods(WorkspaceSwitchAction.prototype);
 
 const AppSwitchAction = new Lang.Class({
     Name: 'AppSwitchAction',
     Extends: Clutter.GestureAction,
+    Signals: { 'activated': {} },
 
     _init : function() {
         this.parent();
@@ -638,7 +658,6 @@ const AppSwitchAction = new Lang.Class({
         return true;
     }
 });
-Signals.addSignalMethods(AppSwitchAction.prototype);
 
 const ResizePopup = new Lang.Class({
     Name: 'ResizePopup',
@@ -920,6 +939,34 @@ const WindowManager = new Lang.Class({
 
         global.display.connect('show-resize-popup', Lang.bind(this, this._showResizePopup));
         global.display.connect('show-pad-osd', Lang.bind(this, this._showPadOsd));
+        global.display.connect('show-osd', Lang.bind(this, function (display, monitorIndex, iconName, label) {
+            let icon = Gio.Icon.new_for_string(iconName);
+            Main.osdWindowManager.show(monitorIndex, icon, label, null);
+        }));
+
+        this._gsdWacomProxy = new GsdWacomProxy(Gio.DBus.session, GSD_WACOM_BUS_NAME,
+                                                GSD_WACOM_OBJECT_PATH,
+                                                Lang.bind(this, function(proxy, error) {
+                                                    if (error) {
+                                                        log(error.message);
+                                                        return;
+                                                    }
+                                                }));
+
+        global.display.connect('pad-mode-switch', Lang.bind(this, function (display, pad, group, mode) {
+            let labels = [];
+
+            //FIXME: Fix num buttons
+            for (let i = 0; i < 50; i++) {
+                let str = display.get_pad_action_label(pad, Meta.PadActionType.BUTTON, i);
+                labels.push(str ? str: '');
+            }
+
+            if (this._gsdWacomProxy) {
+                this._gsdWacomProxy.SetOLEDLabelsRemote(pad.get_device_node(), labels);
+                this._gsdWacomProxy.SetGroupModeLEDRemote(pad.get_device_node(), group, mode);
+            }
+        }));
 
         Main.overview.connect('showing', Lang.bind(this, function() {
             for (let i = 0; i < this._dimmedWindows.length; i++)
@@ -1082,6 +1129,9 @@ const WindowManager = new Lang.Class({
         if (!this._shouldAnimate())
             return false;
 
+        if (!actor.get_texture())
+            return false;
+
         let type = actor.meta_window.get_window_type();
         return types.indexOf(type) >= 0;
     },
@@ -1286,6 +1336,8 @@ const WindowManager = new Lang.Class({
     _sizeChangedWindow: function(shellwm, actor) {
         if (!actor.__fullscreenInfo)
             return;
+        if (this._resizing.indexOf(actor) != -1)
+            return;
 
         let actorClone = actor.__fullscreenInfo.clone;
         let targetRect = actor.meta_window.get_frame_rect();
